import { ParamParseKey } from 'react-router';
import { CreateRouteResult, ParamTypes } from './types';
import { QueryParamConfigMap } from 'serialize-query-params';
/**
 *  Generates various hooks and helpers based on URL pattern and optional parameter types.
 *  @param {string} pattern - the URL pattern (e.g. '/products/:id').
 *  @param {any} urlParamsConfig - object that specifies the types of URL parameters in a pattern (e.g. { id: RequiredNumberParam })
 *  @param {any} searchParamsConfig - object that specifies the types of Search (i.e. ?name=flower&color=yellow) parameters (e.g. { name: StringParam })
 */
export declare function createRoute<ParamKey extends ParamParseKey<Path>, // ParamParseKey<'/asd/:id/:type?'> = 'id' | 'type'
Path extends string, ParamsConfig extends ParamTypes<ParamKey>, // ParamTypes<ParamParseKey<'/asd/:id/:type?'>> = { id?: string|undefined; type?: string|undefined; }
SearchParams extends QueryParamConfigMap>(pattern: Path, urlParamsConfig?: Path extends `${string}:${string}` ? ParamsConfig : undefined, searchParamsConfig?: SearchParams): CreateRouteResult<ParamKey, Path, ParamsConfig, SearchParams>;
